@@ -302,7 +302,7 @@ def drop_columns(df, subset=None, startswith=None, endswith=None, contains=None,
 ###############################################################################
 
 
-def concat(df, out_col, sep=' ', cols=[]):
+def concat(df, out_col, sep=' ', columns=[]):
     """
     Concatenates strings from specified columns into a single string and stores
     the new string value in a new column.
@@ -319,7 +319,7 @@ def concat(df, out_col, sep=' ', cols=[]):
       This is the value used to seperate the
       strings in the different columns when
       combinging them into a single string.
-    cols : list, default = []
+    columns : list, default = []
       The list of columns being concatenated into 
       one string
 
@@ -348,7 +348,7 @@ def concat(df, out_col, sep=' ', cols=[]):
     |  5|  Maggie|      null|Simpson|2021-01-12|  F|ET74 2SP|
     +---+--------+----------+-------+----------+---+--------+
 
-    > concat(df, out_col = 'Full Name', sep = ' ', cols = ['Forename','Middlename','Surname']).show()
+    > concat(df, out_col = 'Full Name', sep = ' ', columns = ['Forename','Middlename','Surname']).show()
     +---+--------+----------+-------+----------+---+--------+--------------------+
     | ID|Forename|Middlename|Surname|       DoB|Sex|Postcode|           Full Name|
     +---+--------+----------+-------+----------+---+--------+--------------------+
@@ -364,7 +364,7 @@ def concat(df, out_col, sep=' ', cols=[]):
 
     df = (df
           .withColumn(out_col,
-                      F.concat_ws(sep, *[F.col(x) for x in cols]))
+                      F.concat_ws(sep, *[F.col(x) for x in columns]))
           )
 
     if sep != '':
@@ -383,7 +383,7 @@ def concat(df, out_col, sep=' ', cols=[]):
 #############################################################################
 
 
-def explode(df, col, on=' ', retain=False, drop_duplicates=True, flag=None):
+def explode(df, column, on=' ', retain=False, drop_duplicates=True, flag=None):
     """
     Splits a string column on specified separator (default=" ") 
     and creates a new row for each element of the split string array
@@ -392,7 +392,7 @@ def explode(df, col, on=' ', retain=False, drop_duplicates=True, flag=None):
     Parameters
     ----------
     df: dataframe function is being applied to
-    col : string 
+    column : string 
       column to be exploded 
     on : string, default = ' ' 
       This argument takes a string or regex value
@@ -434,7 +434,7 @@ def explode(df, col, on=' ', retain=False, drop_duplicates=True, flag=None):
     +---+--------+----------+-------+----------+---+--------+----------------------+
 
     e.g, if you wanted to separate the record's appearance from their personality description:
-    > explode(df,col = 'Description',on = ' ',retain = False,drop_duplicates = True, flag = None).show()
+    > explode(df,column = 'Description',on = ' ',retain = False,drop_duplicates = True, flag = None).show()
     +---+--------+----------+-------+----------+---+--------+------------+
     | ID|Forename|Middlename|Surname|       DoB|Sex|Postcode| Description|
     +---+--------+----------+-------+----------+---+--------+------------+
@@ -451,7 +451,7 @@ def explode(df, col, on=' ', retain=False, drop_duplicates=True, flag=None):
     +---+--------+----------+-------+----------+---+--------+------------+
 
     if you wanted to also keep the original overall description:
-    > explode(df,col = 'Description',on = ' ',retain = True,drop_duplicates = True, flag = None).show()  
+    > explode(df,column = 'Description',on = ' ',retain = True,drop_duplicates = True, flag = None).show()  
     +---+--------+----------+-------+----------+---+--------+----------------------+
     |ID |Forename|Middlename|Surname|DoB       |Sex|Postcode|Description           |
     +---+--------+----------+-------+----------+---+--------+----------------------+
@@ -476,13 +476,13 @@ def explode(df, col, on=' ', retain=False, drop_duplicates=True, flag=None):
     if retain == False:
 
         df = (df
-              .where(F.col(col).rlike(on))
-              .select(*[x for x in df.columns if x != col],
-                      F.explode(F.split(F.col(col), on))
-                      .alias(col))
+              .where(F.col(column).rlike(on))
+              .select(*[x for x in df.columns if x != column],
+                      F.explode(F.split(F.col(column), on))
+                      .alias(column))
               .unionByName((df
-                           .where((F.col(col).rlike(on) == False)
-                                  | (F.col(col).rlike(on).isNull()))))
+                           .where((F.col(column).rlike(on) == False)
+                                  | (F.col(column).rlike(on).isNull()))))
               )
 
     if retain == True:
@@ -490,21 +490,21 @@ def explode(df, col, on=' ', retain=False, drop_duplicates=True, flag=None):
         if flag is None:
 
             df = (df
-                  .where(F.col(col).rlike(on))
-                  .select(*[x for x in df.columns if x != col],
-                          F.explode(F.split(F.col(col), on))
-                          .alias(col))
+                  .where(F.col(column).rlike(on))
+                  .select(*[x for x in df.columns if x != column],
+                          F.explode(F.split(F.col(column), on))
+                          .alias(column))
                   .unionByName(df)
                   )
 
         else:
 
             df = (df
-                  .where(F.col(col).rlike(on))
+                  .where(F.col(column).rlike(on))
                   .withColumn(flag, F.lit(True))
-                  .select(*[x for x in df.columns+[flag] if x != col],
-                          F.explode(F.split(F.col(col), on))
-                          .alias(col))
+                  .select(*[x for x in df.columns+[flag] if x != column],
+                          F.explode(F.split(F.col(column), on))
+                          .alias(column))
                   .unionByName(df.withColumn(flag, F.lit(False)))
                   )
 
@@ -913,6 +913,8 @@ def window(df, window, target, mode, alias=None, drop_na=False):
     """
     Adds window column for count, countDistinct, min, max, or sum operations 
     over window
+    
+    Need to import the union_all function first.
 
     Parameters
     ----------
@@ -997,11 +999,58 @@ def window(df, window, target, mode, alias=None, drop_na=False):
 
     > window(df = df,
              window = 'Sex',
-             target = 'age_at_2022-12-06',
-             mode = 'max',
-             alias= 'oldest_family_member',
+             target = 'age_at_2022-12-09',
+             mode = 'min',
+             alias= 'youngest_per_sex',
              drop_na=False).show()
              
+    +---+----------------+---+--------+----------+-------+----------+--------+-----------------+
+    |Sex|youngest_per_sex| ID|Forename|Middlename|Surname|       DoB|Postcode|age_at_2022-12-09|
+    +---+----------------+---+--------+----------+-------+----------+--------+-----------------+
+    |  F|               1|  2|   Marge|    Juliet|Simpson|1983-03-19|ET74 2SP|               39|
+    |  F|               1|  4|    Lisa|     Marie|Simpson|2014-05-09|ET74 2SP|                8|
+    |  F|               1|  5|  Maggie|      null|Simpson|2021-01-12|ET74 2SP|                1|
+    |  M|              10|  1|   Homer|       Jay|Simpson|1983-05-12|ET74 2SP|               39|
+    |  M|              10|  3|    Bart|     Jo-Jo|Simpson|2012-04-01|ET74 2SP|               10|
+    |  M|              10|  3|    Bart|     Jo-Jo|Simpson|2012-04-01|ET74 2SP|               10|
+    +---+----------------+---+--------+----------+-------+----------+--------+-----------------+
+
+    > window(df = df,
+             window = 'Sex',
+             target = 'age_at_2022-12-09',
+             mode = 'max',
+             alias= 'oldest_per_sex',
+             drop_na=False).show()
+
+    +---+--------------+---+--------+----------+-------+----------+--------+-----------------+
+    |Sex|oldest_per_sex| ID|Forename|Middlename|Surname|       DoB|Postcode|age_at_2022-12-09|
+    +---+--------------+---+--------+----------+-------+----------+--------+-----------------+
+    |  F|            39|  2|   Marge|    Juliet|Simpson|1983-03-19|ET74 2SP|               39|
+    |  F|            39|  4|    Lisa|     Marie|Simpson|2014-05-09|ET74 2SP|                8|
+    |  F|            39|  5|  Maggie|      null|Simpson|2021-01-12|ET74 2SP|                1|
+    |  M|            39|  3|    Bart|     Jo-Jo|Simpson|2012-04-01|ET74 2SP|               10|
+    |  M|            39|  1|   Homer|       Jay|Simpson|1983-05-12|ET74 2SP|               39|
+    |  M|            39|  3|    Bart|     Jo-Jo|Simpson|2012-04-01|ET74 2SP|               10|
+    +---+--------------+---+--------+----------+-------+----------+--------+-----------------+
+
+    > window(df = df,
+             window = 'Sex',
+             target = 'age_at_2022-12-09',
+             mode = 'sum',
+             alias= 'total_age_by_sex',
+             drop_na=False).show()
+             
+    +---+----------------+---+--------+----------+-------+----------+--------+-----------------+
+    |Sex|total_age_by_sex| ID|Forename|Middlename|Surname|       DoB|Postcode|age_at_2022-12-09|
+    +---+----------------+---+--------+----------+-------+----------+--------+-----------------+
+    |  F|              48|  2|   Marge|    Juliet|Simpson|1983-03-19|ET74 2SP|               39|
+    |  F|              48|  4|    Lisa|     Marie|Simpson|2014-05-09|ET74 2SP|                8|
+    |  F|              48|  5|  Maggie|      null|Simpson|2021-01-12|ET74 2SP|                1|
+    |  M|              59|  1|   Homer|       Jay|Simpson|1983-05-12|ET74 2SP|               39|
+    |  M|              59|  3|    Bart|     Jo-Jo|Simpson|2012-04-01|ET74 2SP|               10|
+    |  M|              59|  3|    Bart|     Jo-Jo|Simpson|2012-04-01|ET74 2SP|               10|
+    +---+----------------+---+--------+----------+-------+----------+--------+-----------------+  
+             
     See Also
     --------
     standardisation.standardise_null()
@@ -1160,7 +1209,7 @@ def window(df, window, target, mode, alias=None, drop_na=False):
                     .select(window)
                     )
 
-            df = (union_all(df_1, df_2)
+            df = (union_all(df_1,df_2)
                   .select(window+[alias])
                   .dropDuplicates()
                   .join(df,
